flow

package
v0.0.41 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 16, 2025 License: MIT Imports: 5 Imported by: 0

Documentation

Overview

Package flow is a generated GoMock package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockDataExchangeHandler

type MockDataExchangeHandler struct {
	// contains filtered or unexported fields
}

MockDataExchangeHandler is a mock of DataExchangeHandler interface.

func NewMockDataExchangeHandler

func NewMockDataExchangeHandler(ctrl *gomock.Controller) *MockDataExchangeHandler

NewMockDataExchangeHandler creates a new mock instance.

func (*MockDataExchangeHandler) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockDataExchangeHandler) Handle

Handle mocks base method.

type MockDataExchangeHandlerMockRecorder

type MockDataExchangeHandlerMockRecorder struct {
	// contains filtered or unexported fields
}

MockDataExchangeHandlerMockRecorder is the mock recorder for MockDataExchangeHandler.

func (*MockDataExchangeHandlerMockRecorder) Handle

func (mr *MockDataExchangeHandlerMockRecorder) Handle(ctx, request any) *gomock.Call

Handle indicates an expected call of Handle.

type MockSender

type MockSender struct {
	// contains filtered or unexported fields
}

MockSender is a mock of Sender interface.

func NewMockSender

func NewMockSender(ctrl *gomock.Controller) *MockSender

NewMockSender creates a new mock instance.

func (*MockSender) EXPECT

func (m *MockSender) EXPECT() *MockSenderMockRecorder

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockSender) Send

func (m *MockSender) Send(ctx context.Context, conf *config.Config, req *flow.BaseRequest) (*flow.BaseResponse, error)

Send mocks base method.

type MockSenderMockRecorder

type MockSenderMockRecorder struct {
	// contains filtered or unexported fields
}

MockSenderMockRecorder is the mock recorder for MockSender.

func (*MockSenderMockRecorder) Send

func (mr *MockSenderMockRecorder) Send(ctx, conf, req any) *gomock.Call

Send indicates an expected call of Send.

type MockService

type MockService struct {
	// contains filtered or unexported fields
}

MockService is a mock of Service interface.

func NewMockService

func NewMockService(ctrl *gomock.Controller) *MockService

NewMockService creates a new mock instance.

func (*MockService) Create

func (m *MockService) Create(ctx context.Context, request flow.CreateRequest) (*flow.CreateResponse, error)

Create mocks base method.

func (*MockService) Delete

func (m *MockService) Delete(ctx context.Context, id string) (*flow.SuccessResponse, error)

Delete mocks base method.

func (*MockService) Deprecate

func (m *MockService) Deprecate(ctx context.Context, id string) (*flow.SuccessResponse, error)

Deprecate mocks base method.

func (*MockService) EXPECT

func (m *MockService) EXPECT() *MockServiceMockRecorder

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockService) GeneratePreview

func (m *MockService) GeneratePreview(ctx context.Context, request *flow.PreviewRequest) (*flow.PreviewResponse, error)

GeneratePreview mocks base method.

func (*MockService) Get

Get mocks base method.

func (*MockService) GetFlowMetrics

func (m *MockService) GetFlowMetrics(ctx context.Context, request *flow.MetricsRequest) (*flow.MetricsAPIResponse, error)

GetFlowMetrics mocks base method.

func (*MockService) ListAll

func (m *MockService) ListAll(ctx context.Context) (*flow.ListResponse, error)

ListAll mocks base method.

func (*MockService) ListAssets

func (m *MockService) ListAssets(ctx context.Context, id string) (*flow.RetrieveAssetsResponse, error)

ListAssets mocks base method.

func (*MockService) Publish

func (m *MockService) Publish(ctx context.Context, id string) (*flow.SuccessResponse, error)

Publish mocks base method.

func (*MockService) Update

func (m *MockService) Update(ctx context.Context, id string, request flow.UpdateRequest) (*flow.UpdateResponse, error)

Update mocks base method.

func (*MockService) UpdateFlowJSON

UpdateFlowJSON mocks base method.

type MockServiceMockRecorder

type MockServiceMockRecorder struct {
	// contains filtered or unexported fields
}

MockServiceMockRecorder is the mock recorder for MockService.

func (*MockServiceMockRecorder) Create

func (mr *MockServiceMockRecorder) Create(ctx, request any) *gomock.Call

Create indicates an expected call of Create.

func (*MockServiceMockRecorder) Delete

func (mr *MockServiceMockRecorder) Delete(ctx, id any) *gomock.Call

Delete indicates an expected call of Delete.

func (*MockServiceMockRecorder) Deprecate

func (mr *MockServiceMockRecorder) Deprecate(ctx, id any) *gomock.Call

Deprecate indicates an expected call of Deprecate.

func (*MockServiceMockRecorder) GeneratePreview

func (mr *MockServiceMockRecorder) GeneratePreview(ctx, request any) *gomock.Call

GeneratePreview indicates an expected call of GeneratePreview.

func (*MockServiceMockRecorder) Get

func (mr *MockServiceMockRecorder) Get(ctx, request any) *gomock.Call

Get indicates an expected call of Get.

func (*MockServiceMockRecorder) GetFlowMetrics

func (mr *MockServiceMockRecorder) GetFlowMetrics(ctx, request any) *gomock.Call

GetFlowMetrics indicates an expected call of GetFlowMetrics.

func (*MockServiceMockRecorder) ListAll

func (mr *MockServiceMockRecorder) ListAll(ctx any) *gomock.Call

ListAll indicates an expected call of ListAll.

func (*MockServiceMockRecorder) ListAssets

func (mr *MockServiceMockRecorder) ListAssets(ctx, id any) *gomock.Call

ListAssets indicates an expected call of ListAssets.

func (*MockServiceMockRecorder) Publish

func (mr *MockServiceMockRecorder) Publish(ctx, id any) *gomock.Call

Publish indicates an expected call of Publish.

func (*MockServiceMockRecorder) Update

func (mr *MockServiceMockRecorder) Update(ctx, id, request any) *gomock.Call

Update indicates an expected call of Update.

func (*MockServiceMockRecorder) UpdateFlowJSON

func (mr *MockServiceMockRecorder) UpdateFlowJSON(ctx, request any) *gomock.Call

UpdateFlowJSON indicates an expected call of UpdateFlowJSON.

Jump to