http

package
v0.0.41 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 16, 2025 License: MIT Imports: 5 Imported by: 0

Documentation

Overview

Package http is a generated GoMock package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockRequestInterceptor

type MockRequestInterceptor struct {
	// contains filtered or unexported fields
}

MockRequestInterceptor is a mock of RequestInterceptor interface.

func NewMockRequestInterceptor

func NewMockRequestInterceptor(ctrl *gomock.Controller) *MockRequestInterceptor

NewMockRequestInterceptor creates a new mock instance.

func (*MockRequestInterceptor) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockRequestInterceptor) InterceptRequest

func (m *MockRequestInterceptor) InterceptRequest(ctx context.Context, request *http0.Request) error

InterceptRequest mocks base method.

type MockRequestInterceptorMockRecorder

type MockRequestInterceptorMockRecorder struct {
	// contains filtered or unexported fields
}

MockRequestInterceptorMockRecorder is the mock recorder for MockRequestInterceptor.

func (*MockRequestInterceptorMockRecorder) InterceptRequest

func (mr *MockRequestInterceptorMockRecorder) InterceptRequest(ctx, request any) *gomock.Call

InterceptRequest indicates an expected call of InterceptRequest.

type MockResponseDecoder

type MockResponseDecoder struct {
	// contains filtered or unexported fields
}

MockResponseDecoder is a mock of ResponseDecoder interface.

func NewMockResponseDecoder

func NewMockResponseDecoder(ctrl *gomock.Controller) *MockResponseDecoder

NewMockResponseDecoder creates a new mock instance.

func (*MockResponseDecoder) Decode

func (m *MockResponseDecoder) Decode(ctx context.Context, response *http0.Response) error

Decode mocks base method.

func (*MockResponseDecoder) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

type MockResponseDecoderMockRecorder

type MockResponseDecoderMockRecorder struct {
	// contains filtered or unexported fields
}

MockResponseDecoderMockRecorder is the mock recorder for MockResponseDecoder.

func (*MockResponseDecoderMockRecorder) Decode

func (mr *MockResponseDecoderMockRecorder) Decode(ctx, response any) *gomock.Call

Decode indicates an expected call of Decode.

type MockResponseInterceptor

type MockResponseInterceptor struct {
	// contains filtered or unexported fields
}

MockResponseInterceptor is a mock of ResponseInterceptor interface.

func NewMockResponseInterceptor

func NewMockResponseInterceptor(ctrl *gomock.Controller) *MockResponseInterceptor

NewMockResponseInterceptor creates a new mock instance.

func (*MockResponseInterceptor) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockResponseInterceptor) InterceptResponse

func (m *MockResponseInterceptor) InterceptResponse(ctx context.Context, response *http0.Response) error

InterceptResponse mocks base method.

type MockResponseInterceptorMockRecorder

type MockResponseInterceptorMockRecorder struct {
	// contains filtered or unexported fields
}

MockResponseInterceptorMockRecorder is the mock recorder for MockResponseInterceptor.

func (*MockResponseInterceptorMockRecorder) InterceptResponse

func (mr *MockResponseInterceptorMockRecorder) InterceptResponse(ctx, response any) *gomock.Call

InterceptResponse indicates an expected call of InterceptResponse.

type MockSender

type MockSender[T any] struct {
	// contains filtered or unexported fields
}

MockSender is a mock of Sender interface.

func NewMockSender

func NewMockSender[T any](ctrl *gomock.Controller) *MockSender[T]

NewMockSender creates a new mock instance.

func (*MockSender[T]) EXPECT

func (m *MockSender[T]) EXPECT() *MockSenderMockRecorder[T]

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockSender[T]) Send

func (m *MockSender[T]) Send(ctx context.Context, request *http.Request[T], decoder http.ResponseDecoder) error

Send mocks base method.

type MockSenderMockRecorder

type MockSenderMockRecorder[T any] struct {
	// contains filtered or unexported fields
}

MockSenderMockRecorder is the mock recorder for MockSender.

func (*MockSenderMockRecorder[T]) Send

func (mr *MockSenderMockRecorder[T]) Send(ctx, request, decoder any) *gomock.Call

Send indicates an expected call of Send.

Jump to