message

package
v0.0.41 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 16, 2025 License: MIT Imports: 5 Imported by: 0

Documentation

Overview

Package message is a generated GoMock package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockSender

type MockSender struct {
	// contains filtered or unexported fields
}

MockSender is a mock of Sender interface.

func NewMockSender

func NewMockSender(ctrl *gomock.Controller) *MockSender

NewMockSender creates a new mock instance.

func (*MockSender) EXPECT

func (m *MockSender) EXPECT() *MockSenderMockRecorder

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockSender) Send

func (m *MockSender) Send(ctx context.Context, conf *config.Config, request *message.BaseRequest) (*message.Response, error)

Send mocks base method.

type MockSenderMockRecorder

type MockSenderMockRecorder struct {
	// contains filtered or unexported fields
}

MockSenderMockRecorder is the mock recorder for MockSender.

func (*MockSenderMockRecorder) Send

func (mr *MockSenderMockRecorder) Send(ctx, conf, request any) *gomock.Call

Send indicates an expected call of Send.

type MockService

type MockService struct {
	// contains filtered or unexported fields
}

MockService is a mock of Service interface.

func NewMockService

func NewMockService(ctrl *gomock.Controller) *MockService

NewMockService creates a new mock instance.

func (*MockService) EXPECT

func (m *MockService) EXPECT() *MockServiceMockRecorder

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockService) RequestLocation

func (m *MockService) RequestLocation(ctx context.Context, request *message.Request[string]) (*message.Response, error)

RequestLocation mocks base method.

func (*MockService) SendAudio

func (m *MockService) SendAudio(ctx context.Context, request *message.Request[message.Audio]) (*message.Response, error)

SendAudio mocks base method.

func (*MockService) SendContacts

func (m *MockService) SendContacts(ctx context.Context, request *message.Request[message.Contacts]) (*message.Response, error)

SendContacts mocks base method.

func (*MockService) SendDocument

func (m *MockService) SendDocument(ctx context.Context, request *message.Request[message.Document]) (*message.Response, error)

SendDocument mocks base method.

func (*MockService) SendImage

func (m *MockService) SendImage(ctx context.Context, request *message.Request[message.Image]) (*message.Response, error)

SendImage mocks base method.

func (*MockService) SendInteractiveMessage

func (m *MockService) SendInteractiveMessage(ctx context.Context, request *message.Request[message.Interactive]) (*message.Response, error)

SendInteractiveMessage mocks base method.

func (*MockService) SendLocation

func (m *MockService) SendLocation(ctx context.Context, request *message.Request[message.Location]) (*message.Response, error)

SendLocation mocks base method.

func (*MockService) SendReaction

func (m *MockService) SendReaction(ctx context.Context, request *message.Request[message.Reaction]) (*message.Response, error)

SendReaction mocks base method.

func (*MockService) SendSticker

func (m *MockService) SendSticker(ctx context.Context, request *message.Request[message.Sticker]) (*message.Response, error)

SendSticker mocks base method.

func (*MockService) SendTemplate

func (m *MockService) SendTemplate(ctx context.Context, request *message.Request[message.Template]) (*message.Response, error)

SendTemplate mocks base method.

func (*MockService) SendText

func (m *MockService) SendText(ctx context.Context, request *message.Request[message.Text]) (*message.Response, error)

SendText mocks base method.

func (*MockService) SendVideo

func (m *MockService) SendVideo(ctx context.Context, request *message.Request[message.Video]) (*message.Response, error)

SendVideo mocks base method.

type MockServiceMockRecorder

type MockServiceMockRecorder struct {
	// contains filtered or unexported fields
}

MockServiceMockRecorder is the mock recorder for MockService.

func (*MockServiceMockRecorder) RequestLocation

func (mr *MockServiceMockRecorder) RequestLocation(ctx, request any) *gomock.Call

RequestLocation indicates an expected call of RequestLocation.

func (*MockServiceMockRecorder) SendAudio

func (mr *MockServiceMockRecorder) SendAudio(ctx, request any) *gomock.Call

SendAudio indicates an expected call of SendAudio.

func (*MockServiceMockRecorder) SendContacts

func (mr *MockServiceMockRecorder) SendContacts(ctx, request any) *gomock.Call

SendContacts indicates an expected call of SendContacts.

func (*MockServiceMockRecorder) SendDocument

func (mr *MockServiceMockRecorder) SendDocument(ctx, request any) *gomock.Call

SendDocument indicates an expected call of SendDocument.

func (*MockServiceMockRecorder) SendImage

func (mr *MockServiceMockRecorder) SendImage(ctx, request any) *gomock.Call

SendImage indicates an expected call of SendImage.

func (*MockServiceMockRecorder) SendInteractiveMessage

func (mr *MockServiceMockRecorder) SendInteractiveMessage(ctx, request any) *gomock.Call

SendInteractiveMessage indicates an expected call of SendInteractiveMessage.

func (*MockServiceMockRecorder) SendLocation

func (mr *MockServiceMockRecorder) SendLocation(ctx, request any) *gomock.Call

SendLocation indicates an expected call of SendLocation.

func (*MockServiceMockRecorder) SendReaction

func (mr *MockServiceMockRecorder) SendReaction(ctx, request any) *gomock.Call

SendReaction indicates an expected call of SendReaction.

func (*MockServiceMockRecorder) SendSticker

func (mr *MockServiceMockRecorder) SendSticker(ctx, request any) *gomock.Call

SendSticker indicates an expected call of SendSticker.

func (*MockServiceMockRecorder) SendTemplate

func (mr *MockServiceMockRecorder) SendTemplate(ctx, request any) *gomock.Call

SendTemplate indicates an expected call of SendTemplate.

func (*MockServiceMockRecorder) SendText

func (mr *MockServiceMockRecorder) SendText(ctx, request any) *gomock.Call

SendText indicates an expected call of SendText.

func (*MockServiceMockRecorder) SendVideo

func (mr *MockServiceMockRecorder) SendVideo(ctx, request any) *gomock.Call

SendVideo indicates an expected call of SendVideo.

type MockStatusUpdater

type MockStatusUpdater struct {
	// contains filtered or unexported fields
}

MockStatusUpdater is a mock of StatusUpdater interface.

func NewMockStatusUpdater

func NewMockStatusUpdater(ctrl *gomock.Controller) *MockStatusUpdater

NewMockStatusUpdater creates a new mock instance.

func (*MockStatusUpdater) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockStatusUpdater) UpdateStatus

UpdateStatus mocks base method.

type MockStatusUpdaterMockRecorder

type MockStatusUpdaterMockRecorder struct {
	// contains filtered or unexported fields
}

MockStatusUpdaterMockRecorder is the mock recorder for MockStatusUpdater.

func (*MockStatusUpdaterMockRecorder) UpdateStatus

func (mr *MockStatusUpdaterMockRecorder) UpdateStatus(ctx, request any) *gomock.Call

UpdateStatus indicates an expected call of UpdateStatus.

Jump to