webhooks

package
v0.0.41 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 16, 2025 License: MIT Imports: 6 Imported by: 0

Documentation

Overview

Package webhooks is a generated GoMock package.

Package webhooks is a generated GoMock package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockConfigReader

type MockConfigReader struct {
	// contains filtered or unexported fields
}

MockConfigReader is a mock of ConfigReader interface.

func NewMockConfigReader

func NewMockConfigReader(ctrl *gomock.Controller) *MockConfigReader

NewMockConfigReader creates a new mock instance.

func (*MockConfigReader) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockConfigReader) ReadConfig

func (m *MockConfigReader) ReadConfig(request *http.Request) (*webhooks.Config, error)

ReadConfig mocks base method.

type MockConfigReaderMockRecorder

type MockConfigReaderMockRecorder struct {
	// contains filtered or unexported fields
}

MockConfigReaderMockRecorder is the mock recorder for MockConfigReader.

func (*MockConfigReaderMockRecorder) ReadConfig

func (mr *MockConfigReaderMockRecorder) ReadConfig(request any) *gomock.Call

ReadConfig indicates an expected call of ReadConfig.

type MockEventHandler

type MockEventHandler[S any, T any] struct {
	// contains filtered or unexported fields
}

MockEventHandler is a mock of EventHandler interface.

func NewMockEventHandler

func NewMockEventHandler[S any, T any](ctrl *gomock.Controller) *MockEventHandler[S, T]

NewMockEventHandler creates a new mock instance.

func (*MockEventHandler[S, T]) EXPECT

func (m *MockEventHandler[S, T]) EXPECT() *MockEventHandlerMockRecorder[S, T]

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockEventHandler[S, T]) HandleEvent

func (m *MockEventHandler[S, T]) HandleEvent(ctx context.Context, ntx *S, notification *T) error

HandleEvent mocks base method.

type MockEventHandlerMockRecorder

type MockEventHandlerMockRecorder[S any, T any] struct {
	// contains filtered or unexported fields
}

MockEventHandlerMockRecorder is the mock recorder for MockEventHandler.

func (*MockEventHandlerMockRecorder[S, T]) HandleEvent

func (mr *MockEventHandlerMockRecorder[S, T]) HandleEvent(ctx, ntx, notification any) *gomock.Call

HandleEvent indicates an expected call of HandleEvent.

type MockMessageChangeValueHandler

type MockMessageChangeValueHandler[T any] struct {
	// contains filtered or unexported fields
}

MockMessageChangeValueHandler is a mock of MessageChangeValueHandler interface.

func NewMockMessageChangeValueHandler

func NewMockMessageChangeValueHandler[T any](ctrl *gomock.Controller) *MockMessageChangeValueHandler[T]

NewMockMessageChangeValueHandler creates a new mock instance.

func (*MockMessageChangeValueHandler[T]) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockMessageChangeValueHandler[T]) Handle

func (m *MockMessageChangeValueHandler[T]) Handle(ctx context.Context, notificationCtx *webhooks.MessageNotificationContext, value []*T) error

Handle mocks base method.

type MockMessageChangeValueHandlerMockRecorder

type MockMessageChangeValueHandlerMockRecorder[T any] struct {
	// contains filtered or unexported fields
}

MockMessageChangeValueHandlerMockRecorder is the mock recorder for MockMessageChangeValueHandler.

func (*MockMessageChangeValueHandlerMockRecorder[T]) Handle

func (mr *MockMessageChangeValueHandlerMockRecorder[T]) Handle(ctx, notificationCtx, value any) *gomock.Call

Handle indicates an expected call of Handle.

type MockMessageErrorsHandler

type MockMessageErrorsHandler struct {
	// contains filtered or unexported fields
}

MockMessageErrorsHandler is a mock of MessageErrorsHandler interface.

func NewMockMessageErrorsHandler

func NewMockMessageErrorsHandler(ctrl *gomock.Controller) *MockMessageErrorsHandler

NewMockMessageErrorsHandler creates a new mock instance.

func (*MockMessageErrorsHandler) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockMessageErrorsHandler) Handle

Handle mocks base method.

type MockMessageErrorsHandlerMockRecorder

type MockMessageErrorsHandlerMockRecorder struct {
	// contains filtered or unexported fields
}

MockMessageErrorsHandlerMockRecorder is the mock recorder for MockMessageErrorsHandler.

func (*MockMessageErrorsHandlerMockRecorder) Handle

func (mr *MockMessageErrorsHandlerMockRecorder) Handle(ctx, notificationContext, info, arg3 any) *gomock.Call

Handle indicates an expected call of Handle.

type MockMessageHandler

type MockMessageHandler[T any] struct {
	// contains filtered or unexported fields
}

MockMessageHandler is a mock of MessageHandler interface.

func NewMockMessageHandler

func NewMockMessageHandler[T any](ctrl *gomock.Controller) *MockMessageHandler[T]

NewMockMessageHandler creates a new mock instance.

func (*MockMessageHandler[T]) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockMessageHandler[T]) Handle

func (m *MockMessageHandler[T]) Handle(ctx context.Context, notificationCtx *webhooks.MessageNotificationContext, info *webhooks.MessageInfo, message *T) error

Handle mocks base method.

type MockMessageHandlerMockRecorder

type MockMessageHandlerMockRecorder[T any] struct {
	// contains filtered or unexported fields
}

MockMessageHandlerMockRecorder is the mock recorder for MockMessageHandler.

func (*MockMessageHandlerMockRecorder[T]) Handle

func (mr *MockMessageHandlerMockRecorder[T]) Handle(ctx, notificationCtx, info, message any) *gomock.Call

Handle indicates an expected call of Handle.

type MockNotificationHandler

type MockNotificationHandler struct {
	// contains filtered or unexported fields
}

MockNotificationHandler is a mock of NotificationHandler interface.

func NewMockNotificationHandler

func NewMockNotificationHandler(ctrl *gomock.Controller) *MockNotificationHandler

NewMockNotificationHandler creates a new mock instance.

func (*MockNotificationHandler) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockNotificationHandler) HandleNotification

func (m *MockNotificationHandler) HandleNotification(ctx context.Context, notification *webhooks.Notification) *webhooks.Response

HandleNotification mocks base method.

type MockNotificationHandlerMockRecorder

type MockNotificationHandlerMockRecorder struct {
	// contains filtered or unexported fields
}

MockNotificationHandlerMockRecorder is the mock recorder for MockNotificationHandler.

func (*MockNotificationHandlerMockRecorder) HandleNotification

func (mr *MockNotificationHandlerMockRecorder) HandleNotification(ctx, notification any) *gomock.Call

HandleNotification indicates an expected call of HandleNotification.

Jump to