crypto

package
v0.0.41 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 16, 2025 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

const ErrCreateAppSecretProof = whatsapp.Error("failed to create appsecret_proof")

Variables

This section is empty.

Functions

func GenerateAppSecretProof

func GenerateAppSecretProof(accessToken, appSecret string) (string, error)

GenerateAppSecretProof generates the app secret proof required for secure API calls. It creates an HMAC-SHA-256 hash using the access token and the app secret.

Types

This section is empty.

Jump to