Documentation
¶
Overview ¶
Package http is a generated GoMock package.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MockRequestInterceptor ¶
type MockRequestInterceptor struct {
// contains filtered or unexported fields
}
MockRequestInterceptor is a mock of RequestInterceptor interface.
func NewMockRequestInterceptor ¶
func NewMockRequestInterceptor(ctrl *gomock.Controller) *MockRequestInterceptor
NewMockRequestInterceptor creates a new mock instance.
func (*MockRequestInterceptor) EXPECT ¶
func (m *MockRequestInterceptor) EXPECT() *MockRequestInterceptorMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockRequestInterceptor) InterceptRequest ¶
func (m *MockRequestInterceptor) InterceptRequest(ctx context.Context, request *http0.Request) error
InterceptRequest mocks base method.
type MockRequestInterceptorMockRecorder ¶
type MockRequestInterceptorMockRecorder struct {
// contains filtered or unexported fields
}
MockRequestInterceptorMockRecorder is the mock recorder for MockRequestInterceptor.
func (*MockRequestInterceptorMockRecorder) InterceptRequest ¶
func (mr *MockRequestInterceptorMockRecorder) InterceptRequest(ctx, request any) *gomock.Call
InterceptRequest indicates an expected call of InterceptRequest.
type MockResponseDecoder ¶
type MockResponseDecoder struct {
// contains filtered or unexported fields
}
MockResponseDecoder is a mock of ResponseDecoder interface.
func NewMockResponseDecoder ¶
func NewMockResponseDecoder(ctrl *gomock.Controller) *MockResponseDecoder
NewMockResponseDecoder creates a new mock instance.
func (*MockResponseDecoder) EXPECT ¶
func (m *MockResponseDecoder) EXPECT() *MockResponseDecoderMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
type MockResponseDecoderMockRecorder ¶
type MockResponseDecoderMockRecorder struct {
// contains filtered or unexported fields
}
MockResponseDecoderMockRecorder is the mock recorder for MockResponseDecoder.
type MockResponseInterceptor ¶
type MockResponseInterceptor struct {
// contains filtered or unexported fields
}
MockResponseInterceptor is a mock of ResponseInterceptor interface.
func NewMockResponseInterceptor ¶
func NewMockResponseInterceptor(ctrl *gomock.Controller) *MockResponseInterceptor
NewMockResponseInterceptor creates a new mock instance.
func (*MockResponseInterceptor) EXPECT ¶
func (m *MockResponseInterceptor) EXPECT() *MockResponseInterceptorMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockResponseInterceptor) InterceptResponse ¶
func (m *MockResponseInterceptor) InterceptResponse(ctx context.Context, response *http0.Response) error
InterceptResponse mocks base method.
type MockResponseInterceptorMockRecorder ¶
type MockResponseInterceptorMockRecorder struct {
// contains filtered or unexported fields
}
MockResponseInterceptorMockRecorder is the mock recorder for MockResponseInterceptor.
func (*MockResponseInterceptorMockRecorder) InterceptResponse ¶
func (mr *MockResponseInterceptorMockRecorder) InterceptResponse(ctx, response any) *gomock.Call
InterceptResponse indicates an expected call of InterceptResponse.
type MockSender ¶
type MockSender[T any] struct { // contains filtered or unexported fields }
MockSender is a mock of Sender interface.
func NewMockSender ¶
func NewMockSender[T any](ctrl *gomock.Controller) *MockSender[T]
NewMockSender creates a new mock instance.
func (*MockSender[T]) EXPECT ¶
func (m *MockSender[T]) EXPECT() *MockSenderMockRecorder[T]
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockSender[T]) Send ¶
func (m *MockSender[T]) Send(ctx context.Context, request *http.Request[T], decoder http.ResponseDecoder) error
Send mocks base method.
type MockSenderMockRecorder ¶
type MockSenderMockRecorder[T any] struct { // contains filtered or unexported fields }
MockSenderMockRecorder is the mock recorder for MockSender.