Documentation
¶
Overview ¶
Package webhooks is a generated GoMock package.
Package webhooks is a generated GoMock package.
Index ¶
- type MockConfigReader
- type MockConfigReaderMockRecorder
- type MockEventHandler
- type MockEventHandlerMockRecorder
- type MockMessageChangeValueHandler
- type MockMessageChangeValueHandlerMockRecorder
- type MockMessageErrorsHandler
- type MockMessageErrorsHandlerMockRecorder
- type MockMessageHandler
- type MockMessageHandlerMockRecorder
- type MockNotificationHandler
- type MockNotificationHandlerMockRecorder
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MockConfigReader ¶
type MockConfigReader struct {
// contains filtered or unexported fields
}
MockConfigReader is a mock of ConfigReader interface.
func NewMockConfigReader ¶
func NewMockConfigReader(ctrl *gomock.Controller) *MockConfigReader
NewMockConfigReader creates a new mock instance.
func (*MockConfigReader) EXPECT ¶
func (m *MockConfigReader) EXPECT() *MockConfigReaderMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockConfigReader) ReadConfig ¶
ReadConfig mocks base method.
type MockConfigReaderMockRecorder ¶
type MockConfigReaderMockRecorder struct {
// contains filtered or unexported fields
}
MockConfigReaderMockRecorder is the mock recorder for MockConfigReader.
func (*MockConfigReaderMockRecorder) ReadConfig ¶
func (mr *MockConfigReaderMockRecorder) ReadConfig(request any) *gomock.Call
ReadConfig indicates an expected call of ReadConfig.
type MockEventHandler ¶
MockEventHandler is a mock of EventHandler interface.
func NewMockEventHandler ¶
func NewMockEventHandler[S any, T any](ctrl *gomock.Controller) *MockEventHandler[S, T]
NewMockEventHandler creates a new mock instance.
func (*MockEventHandler[S, T]) EXPECT ¶
func (m *MockEventHandler[S, T]) EXPECT() *MockEventHandlerMockRecorder[S, T]
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockEventHandler[S, T]) HandleEvent ¶
func (m *MockEventHandler[S, T]) HandleEvent(ctx context.Context, ntx *S, notification *T) error
HandleEvent mocks base method.
type MockEventHandlerMockRecorder ¶
type MockEventHandlerMockRecorder[S any, T any] struct { // contains filtered or unexported fields }
MockEventHandlerMockRecorder is the mock recorder for MockEventHandler.
func (*MockEventHandlerMockRecorder[S, T]) HandleEvent ¶
func (mr *MockEventHandlerMockRecorder[S, T]) HandleEvent(ctx, ntx, notification any) *gomock.Call
HandleEvent indicates an expected call of HandleEvent.
type MockMessageChangeValueHandler ¶
type MockMessageChangeValueHandler[T any] struct { // contains filtered or unexported fields }
MockMessageChangeValueHandler is a mock of MessageChangeValueHandler interface.
func NewMockMessageChangeValueHandler ¶
func NewMockMessageChangeValueHandler[T any](ctrl *gomock.Controller) *MockMessageChangeValueHandler[T]
NewMockMessageChangeValueHandler creates a new mock instance.
func (*MockMessageChangeValueHandler[T]) EXPECT ¶
func (m *MockMessageChangeValueHandler[T]) EXPECT() *MockMessageChangeValueHandlerMockRecorder[T]
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockMessageChangeValueHandler[T]) Handle ¶
func (m *MockMessageChangeValueHandler[T]) Handle(ctx context.Context, notificationCtx *webhooks.MessageNotificationContext, value []*T) error
Handle mocks base method.
type MockMessageChangeValueHandlerMockRecorder ¶
type MockMessageChangeValueHandlerMockRecorder[T any] struct { // contains filtered or unexported fields }
MockMessageChangeValueHandlerMockRecorder is the mock recorder for MockMessageChangeValueHandler.
type MockMessageErrorsHandler ¶
type MockMessageErrorsHandler struct {
// contains filtered or unexported fields
}
MockMessageErrorsHandler is a mock of MessageErrorsHandler interface.
func NewMockMessageErrorsHandler ¶
func NewMockMessageErrorsHandler(ctrl *gomock.Controller) *MockMessageErrorsHandler
NewMockMessageErrorsHandler creates a new mock instance.
func (*MockMessageErrorsHandler) EXPECT ¶
func (m *MockMessageErrorsHandler) EXPECT() *MockMessageErrorsHandlerMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockMessageErrorsHandler) Handle ¶
func (m *MockMessageErrorsHandler) Handle(ctx context.Context, notificationContext *webhooks.MessageNotificationContext, info *webhooks.MessageInfo, arg3 []*errors.Error) error
Handle mocks base method.
type MockMessageErrorsHandlerMockRecorder ¶
type MockMessageErrorsHandlerMockRecorder struct {
// contains filtered or unexported fields
}
MockMessageErrorsHandlerMockRecorder is the mock recorder for MockMessageErrorsHandler.
type MockMessageHandler ¶
type MockMessageHandler[T any] struct { // contains filtered or unexported fields }
MockMessageHandler is a mock of MessageHandler interface.
func NewMockMessageHandler ¶
func NewMockMessageHandler[T any](ctrl *gomock.Controller) *MockMessageHandler[T]
NewMockMessageHandler creates a new mock instance.
func (*MockMessageHandler[T]) EXPECT ¶
func (m *MockMessageHandler[T]) EXPECT() *MockMessageHandlerMockRecorder[T]
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockMessageHandler[T]) Handle ¶
func (m *MockMessageHandler[T]) Handle(ctx context.Context, notificationCtx *webhooks.MessageNotificationContext, info *webhooks.MessageInfo, message *T) error
Handle mocks base method.
type MockMessageHandlerMockRecorder ¶
type MockMessageHandlerMockRecorder[T any] struct { // contains filtered or unexported fields }
MockMessageHandlerMockRecorder is the mock recorder for MockMessageHandler.
type MockNotificationHandler ¶
type MockNotificationHandler struct {
// contains filtered or unexported fields
}
MockNotificationHandler is a mock of NotificationHandler interface.
func NewMockNotificationHandler ¶
func NewMockNotificationHandler(ctrl *gomock.Controller) *MockNotificationHandler
NewMockNotificationHandler creates a new mock instance.
func (*MockNotificationHandler) EXPECT ¶
func (m *MockNotificationHandler) EXPECT() *MockNotificationHandlerMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockNotificationHandler) HandleNotification ¶
func (m *MockNotificationHandler) HandleNotification(ctx context.Context, notification *webhooks.Notification) *webhooks.Response
HandleNotification mocks base method.
type MockNotificationHandlerMockRecorder ¶
type MockNotificationHandlerMockRecorder struct {
// contains filtered or unexported fields
}
MockNotificationHandlerMockRecorder is the mock recorder for MockNotificationHandler.
func (*MockNotificationHandlerMockRecorder) HandleNotification ¶
func (mr *MockNotificationHandlerMockRecorder) HandleNotification(ctx, notification any) *gomock.Call
HandleNotification indicates an expected call of HandleNotification.