Documentation
¶
Index ¶
Constants ¶
const ErrCreateAppSecretProof = whatsapp.Error("failed to create appsecret_proof")
Variables ¶
This section is empty.
Functions ¶
func GenerateAppSecretProof ¶
GenerateAppSecretProof generates the app secret proof required for secure API calls. It creates an HMAC-SHA-256 hash using the access token and the app secret.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.